@@ -1,5 +1,7 @@
+import datetime
 import os
 
+from django.conf import settings
 from django.core.files.storage import default_storage
 from django.core.files.base import ContentFile
 
@@ -11,12 +13,17 @@ class DefaultStorageUploadBackend(AbstractUploadBackend):
     Uses Django's default storage backend to store the uploaded files
     see https://docs.djangoproject.com/en/dev/topics/files/#file-storage
     """
-    
-    UPLOAD_DIR = 'uploads'
+
+    UPLOAD_DIR = getattr(settings, "UPLOAD_DIR", "uploads")
+
+    def _get_upload_dir(self):
+        if callable(self.UPLOAD_DIR):
+            return self.UPLOAD_DIR()
+        return datetime.datetime.now().strftime(self.UPLOAD_DIR)
 
     def setup(self, filename, *args, **kwargs):
-        # join UPLOAD_DIR with filename 
-        new_path = os.path.join(self.UPLOAD_DIR, filename)
+        # join UPLOAD_DIR with filename.
+        new_path = os.path.join(self._get_upload_dir(), filename)
 
         # save empty file in default storage with path = new_path
         self.path = default_storage.save(new_path, ContentFile(''))
